import { AwsHandlerExecutionContext, AwsSdkFeatures } from "@aws-sdk/types";
export declare function setFeature<F extends keyof AwsSdkFeatures>(
  context: AwsHandlerExecutionContext,
  feature: F,
  value: AwsSdkFeatures[F]
): void;
