export declare const state: {
    warningEmitted: boolean;
};
/**
 * @internal
 *
 * Emits warning if the provided Node.js version string is
 * pending deprecation by AWS SDK JSv3.
 *
 * @param version - The Node.js version string.
 */
export declare const emitWarningIfUnsupportedVersion: (version: string) => void;
