export type AccountIdEndpointMode = "disabled" | "preferred" | "required";
export declare const DEFAULT_ACCOUNT_ID_ENDPOINT_MODE = "preferred";
export declare const ACCOUNT_ID_ENDPOINT_MODE_VALUES: AccountIdEndpointMode[];
export declare function validateAccountIdEndpointMode(
  value: any
): value is AccountIdEndpointMode;
