/**
 * @internal
 *
 * Forwards to Smithy's expectUnion function, but also ignores
 * the `__type` field if it is present.
 */
export declare const awsExpectUnion: (value: unknown) => Record<string, any> | undefined;
