/**
 * @public
 */
export type AccountIdEndpointMode = "disabled" | "preferred" | "required";
/**
 * @internal
 */
export declare const DEFAULT_ACCOUNT_ID_ENDPOINT_MODE = "preferred";
/**
 * @internal
 */
export declare const ACCOUNT_ID_ENDPOINT_MODE_VALUES: AccountIdEndpointMode[];
/**
 * @internal
 */
export declare function validateAccountIdEndpointMode(value: any): value is AccountIdEndpointMode;
