/**
 * Converts a comma-separated string into an array of trimmed strings
 * @param str The comma-separated input string to split
 * @returns Array of trimmed strings split from the input
 *
 * @internal
 */
export declare const getArrayForCommaSeparatedString: (str: string) => string[];
