import { HttpResponse, SerdeContext } from "@smithy/types";
export declare const parseXmlBody: (
  streamBody: any,
  context: SerdeContext
) => any;
export declare const parseXmlErrorBody: (
  errorBody: any,
  context: SerdeContext
) => Promise<any>;
export declare const loadRestXmlErrorCode: (
  output: HttpResponse,
  data: any
) => string | undefined;
