import { LoadedConfigSelectors } from "@smithy/node-config-provider";
import { AccountIdEndpointMode } from "./AccountIdEndpointModeConstants";
export declare const ENV_ACCOUNT_ID_ENDPOINT_MODE =
  "AWS_ACCOUNT_ID_ENDPOINT_MODE";
export declare const CONFIG_ACCOUNT_ID_ENDPOINT_MODE =
  "account_id_endpoint_mode";
export declare const NODE_ACCOUNT_ID_ENDPOINT_MODE_CONFIG_OPTIONS: LoadedConfigSelectors<AccountIdEndpointMode>;
