/**
 * @internal
 *
 * Returns a date that is corrected for clock skew.
 *
 * @param systemClockOffset The offset of the system clock in milliseconds.
 */
export declare const getSkewCorrectedDate: (systemClockOffset: number) => Date;
