import {
  AttributedAwsCredentialIdentity,
  AwsSdkCredentialsFeatures,
} from "@aws-sdk/types";
export declare function setCredentialFeature<
  F extends keyof AwsSdkCredentialsFeatures
>(
  credentials: AttributedAwsCredentialIdentity,
  feature: F,
  value: AwsSdkCredentialsFeatures[F]
): AttributedAwsCredentialIdentity;
